@@ -13,7 +13,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'BLDSHARED': 'gcc -shared -Wl,--enable-auto-image-base',
  'BUILDEXE': '.exe',
  'BUILDPYTHON': 'python.exe',
- 'BUILD_GNU_TYPE': 'x86_64-pc-cygwin',
+ 'BUILD_GNU_TYPE': 'i686-pc-cygwin',
  'BYTESTR_DEPS': '\\',
  'CC': 'gcc',
  'CCSHARED': '',
@@ -21,8 +21,13 @@ build_time_vars = {'ABIFLAGS': 'm',
            '-Wstrict-prototypes -ggdb -O2 -pipe -Wall -Werror=format-security '
            '-Wp,-D_FORTIFY_SOURCE=2 -fstack-protector-strong '
            '--param=ssp-buffer-size=4 '
-           '-fdebug-prefix-map=/usr/src/ports/python35/python35-3.5.6-1.x86_64/build=/usr/src/debug/python35-3.5.6-1 '
-           '-fdebug-prefix-map=/usr/src/ports/python35/python35-3.5.6-1.x86_64/src/Python-3.5.6=/usr/src/debug/python35-3.5.6-1',
+           '-fdebug-prefix-map=/usr/src/ports/python35/python35-3.5.7-1.i686/build=/usr/src/debug/python35-3.5.7-1 '
+           '-fdebug-prefix-map=/usr/src/ports/python35/python35-3.5.7-1.i686/src/Python-3.5.7=/usr/src/debug/python35-3.5.7-1 '
+           '-ggdb -O2 -pipe -Wall -Werror=format-security '
+           '-Wp,-D_FORTIFY_SOURCE=2 -fstack-protector-strong '
+           '--param=ssp-buffer-size=4 '
+           '-fdebug-prefix-map=/usr/src/ports/python35/python35-3.5.7-1.i686/build=/usr/src/debug/python35-3.5.7-1 '
+           '-fdebug-prefix-map=/usr/src/ports/python35/python35-3.5.7-1.i686/src/Python-3.5.7=/usr/src/debug/python35-3.5.7-1',
  'CFLAGSFORSHARED': '',
  'CFLAGS_ALIASING': '',
  'CFLAGS_NODIST': '',
@@ -31,12 +36,12 @@ build_time_vars = {'ABIFLAGS': 'm',
  'CONFIGURE_CFLAGS': '-ggdb -O2 -pipe -Wall -Werror=format-security '
                      '-Wp,-D_FORTIFY_SOURCE=2 -fstack-protector-strong '
                      '--param=ssp-buffer-size=4 '
-                     '-fdebug-prefix-map=/usr/src/ports/python35/python35-3.5.6-1.x86_64/build=/usr/src/debug/python35-3.5.6-1 '
-                     '-fdebug-prefix-map=/usr/src/ports/python35/python35-3.5.6-1.x86_64/src/Python-3.5.6=/usr/src/debug/python35-3.5.6-1',
+                     '-fdebug-prefix-map=/usr/src/ports/python35/python35-3.5.7-1.i686/build=/usr/src/debug/python35-3.5.7-1 '
+                     '-fdebug-prefix-map=/usr/src/ports/python35/python35-3.5.7-1.i686/src/Python-3.5.7=/usr/src/debug/python35-3.5.7-1',
  'CONFIGURE_CFLAGS_NODIST': '-Werror=declaration-after-statement',
  'CONFIGURE_CPPFLAGS': '',
  'CONFIGURE_LDFLAGS': '',
- 'CONFIG_ARGS': "'--srcdir=/usr/src/ports/python35/python35-3.5.6-1.x86_64/src/Python-3.5.6' "
+ 'CONFIG_ARGS': "'--srcdir=/usr/src/ports/python35/python35-3.5.7-1.i686/src/Python-3.5.7' "
                 "'--prefix=/usr' '--exec-prefix=/usr' '--localstatedir=/var' "
                 "'--sysconfdir=/etc' '--docdir=/usr/share/doc/python35' "
                 "'--htmldir=/usr/share/doc/python35/html' '-C' "
@@ -47,18 +52,18 @@ build_time_vars = {'ABIFLAGS': 'm',
                 "'CFLAGS=-ggdb -O2 -pipe -Wall -Werror=format-security "
                 '-Wp,-D_FORTIFY_SOURCE=2 -fstack-protector-strong '
                 '--param=ssp-buffer-size=4 '
-                '-fdebug-prefix-map=/usr/src/ports/python35/python35-3.5.6-1.x86_64/build=/usr/src/debug/python35-3.5.6-1 '
-                "-fdebug-prefix-map=/usr/src/ports/python35/python35-3.5.6-1.x86_64/src/Python-3.5.6=/usr/src/debug/python35-3.5.6-1' "
+                '-fdebug-prefix-map=/usr/src/ports/python35/python35-3.5.7-1.i686/build=/usr/src/debug/python35-3.5.7-1 '
+                "-fdebug-prefix-map=/usr/src/ports/python35/python35-3.5.7-1.i686/src/Python-3.5.7=/usr/src/debug/python35-3.5.7-1' "
                 "'LDFLAGS=' 'LIBS=' 'CPPFLAGS='",
  'CONFINCLUDEDIR': '/usr/include',
  'CONFINCLUDEPY': '/usr/include/python3.5m',
  'COREPYTHONPATH': ':plat-cygwin',
- 'COVERAGE_INFO': '/usr/src/ports/python35/python35-3.5.6-1.x86_64/build/coverage.info',
- 'COVERAGE_REPORT': '/usr/src/ports/python35/python35-3.5.6-1.x86_64/build/lcov-report',
+ 'COVERAGE_INFO': '/usr/src/ports/python35/python35-3.5.7-1.i686/build/coverage.info',
+ 'COVERAGE_REPORT': '/usr/src/ports/python35/python35-3.5.7-1.i686/build/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov '
                             'report"',
  'CPPFLAGS': '-IObjects -IInclude -IPython -I. '
-             '-I/usr/src/ports/python35/python35-3.5.6-1.x86_64/src/Python-3.5.6/Include',
+             '-I/usr/src/ports/python35/python35-3.5.7-1.i686/src/Python-3.5.7/Include',
  'CXX': 'g++',
  'DESTDIRS': '/usr /usr/lib /usr/lib/python3.5 /usr/lib/python3.5/lib-dynload',
  'DESTLIB': '/usr/lib/python3.5',
@@ -83,7 +88,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'EXTRAMACHDEPPATH': '',
  'EXTRATESTOPTS': '',
  'EXTRA_CFLAGS': '',
- 'EXT_SUFFIX': '.cpython-35m-x86_64-cygwin.dll',
+ 'EXT_SUFFIX': '.cpython-35m-i386-cygwin.dll',
  'FILEMODE': 644,
  'FLOCK_NEEDS_LIBBSD': 0,
  'GETPGRP_HAVE_ARG': 0,
@@ -185,9 +190,9 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_GAI_STRERROR': 1,
  'HAVE_GAMMA': 1,
  'HAVE_GCC_ASM_FOR_MC68881': 0,
- 'HAVE_GCC_ASM_FOR_X64': 1,
+ 'HAVE_GCC_ASM_FOR_X64': 0,
  'HAVE_GCC_ASM_FOR_X87': 1,
- 'HAVE_GCC_UINT128_T': 1,
+ 'HAVE_GCC_UINT128_T': 0,
  'HAVE_GETADDRINFO': 1,
  'HAVE_GETC_UNLOCKED': 1,
  'HAVE_GETENTROPY': 1,
@@ -237,7 +242,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_KILLPG': 1,
  'HAVE_KQUEUE': 0,
  'HAVE_LANGINFO_H': 1,
- 'HAVE_LARGEFILE_SUPPORT': 0,
+ 'HAVE_LARGEFILE_SUPPORT': 1,
  'HAVE_LCHFLAGS': 0,
  'HAVE_LCHMOD': 0,
  'HAVE_LCHOWN': 1,
@@ -468,7 +473,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_WRITEV': 1,
  'HAVE_ZLIB_COPY': 1,
  'HAVE__GETPTY': 0,
- 'HOST_GNU_TYPE': 'x86_64-pc-cygwin',
+ 'HOST_GNU_TYPE': 'i686-pc-cygwin',
  'INCLDIRSTOMAKE': '/usr/include /usr/include /usr/include/python3.5m '
                    '/usr/include/python3.5m',
  'INCLUDEDIR': '/usr/include',
@@ -520,7 +525,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'MAINCC': 'gcc',
  'MAJOR_IN_MKDEV': 0,
  'MAJOR_IN_SYSMACROS': 0,
- 'MAKESETUP': '/usr/src/ports/python35/python35-3.5.6-1.x86_64/src/Python-3.5.6/Modules/makesetup',
+ 'MAKESETUP': '/usr/src/ports/python35/python35-3.5.7-1.i686/src/Python-3.5.7/Modules/makesetup',
  'MANDIR': '/usr/share/man',
  'MKDIR_P': '/usr/bin/mkdir -p',
  'MODLIBS': '',
@@ -587,21 +592,31 @@ build_time_vars = {'ABIFLAGS': 'm',
               '-Wstrict-prototypes -ggdb -O2 -pipe -Wall '
               '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
               '-fstack-protector-strong --param=ssp-buffer-size=4 '
-              '-fdebug-prefix-map=/usr/src/ports/python35/python35-3.5.6-1.x86_64/build=/usr/src/debug/python35-3.5.6-1 '
-              '-fdebug-prefix-map=/usr/src/ports/python35/python35-3.5.6-1.x86_64/src/Python-3.5.6=/usr/src/debug/python35-3.5.6-1',
+              '-fdebug-prefix-map=/usr/src/ports/python35/python35-3.5.7-1.i686/build=/usr/src/debug/python35-3.5.7-1 '
+              '-fdebug-prefix-map=/usr/src/ports/python35/python35-3.5.7-1.i686/src/Python-3.5.7=/usr/src/debug/python35-3.5.7-1 '
+              '-ggdb -O2 -pipe -Wall -Werror=format-security '
+              '-Wp,-D_FORTIFY_SOURCE=2 -fstack-protector-strong '
+              '--param=ssp-buffer-size=4 '
+              '-fdebug-prefix-map=/usr/src/ports/python35/python35-3.5.7-1.i686/build=/usr/src/debug/python35-3.5.7-1 '
+              '-fdebug-prefix-map=/usr/src/ports/python35/python35-3.5.7-1.i686/src/Python-3.5.7=/usr/src/debug/python35-3.5.7-1',
  'PY_CFLAGS_NODIST': '-Werror=declaration-after-statement',
  'PY_CORE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv -O3 '
                    '-Wall -Wstrict-prototypes -ggdb -O2 -pipe -Wall '
                    '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
                    '-fstack-protector-strong --param=ssp-buffer-size=4 '
-                   '-fdebug-prefix-map=/usr/src/ports/python35/python35-3.5.6-1.x86_64/build=/usr/src/debug/python35-3.5.6-1 '
-                   '-fdebug-prefix-map=/usr/src/ports/python35/python35-3.5.6-1.x86_64/src/Python-3.5.6=/usr/src/debug/python35-3.5.6-1 '
+                   '-fdebug-prefix-map=/usr/src/ports/python35/python35-3.5.7-1.i686/build=/usr/src/debug/python35-3.5.7-1 '
+                   '-fdebug-prefix-map=/usr/src/ports/python35/python35-3.5.7-1.i686/src/Python-3.5.7=/usr/src/debug/python35-3.5.7-1 '
+                   '-ggdb -O2 -pipe -Wall -Werror=format-security '
+                   '-Wp,-D_FORTIFY_SOURCE=2 -fstack-protector-strong '
+                   '--param=ssp-buffer-size=4 '
+                   '-fdebug-prefix-map=/usr/src/ports/python35/python35-3.5.7-1.i686/build=/usr/src/debug/python35-3.5.7-1 '
+                   '-fdebug-prefix-map=/usr/src/ports/python35/python35-3.5.7-1.i686/src/Python-3.5.7=/usr/src/debug/python35-3.5.7-1 '
                    '-Werror=declaration-after-statement -IObjects -IInclude '
                    '-IPython -I. '
-                   '-I/usr/src/ports/python35/python35-3.5.6-1.x86_64/src/Python-3.5.6/Include  '
+                   '-I/usr/src/ports/python35/python35-3.5.7-1.i686/src/Python-3.5.7/Include  '
                    '-DPy_BUILD_CORE',
  'PY_CPPFLAGS': '-IObjects -IInclude -IPython -I. '
-                '-I/usr/src/ports/python35/python35-3.5.6-1.x86_64/src/Python-3.5.6/Include',
+                '-I/usr/src/ports/python35/python35-3.5.7-1.i686/src/Python-3.5.7/Include',
  'PY_FORMAT_LONG_LONG': '"ll"',
  'PY_FORMAT_SIZE_T': '"z"',
  'PY_LDFLAGS': '',
@@ -627,22 +642,22 @@ build_time_vars = {'ABIFLAGS': 'm',
  'SIZEOF_FLOAT': 4,
  'SIZEOF_FPOS_T': 8,
  'SIZEOF_INT': 4,
- 'SIZEOF_LONG': 8,
- 'SIZEOF_LONG_DOUBLE': 16,
+ 'SIZEOF_LONG': 4,
+ 'SIZEOF_LONG_DOUBLE': 12,
  'SIZEOF_LONG_LONG': 8,
  'SIZEOF_OFF_T': 8,
  'SIZEOF_PID_T': 4,
- 'SIZEOF_PTHREAD_T': 8,
+ 'SIZEOF_PTHREAD_T': 4,
  'SIZEOF_SHORT': 2,
- 'SIZEOF_SIZE_T': 8,
- 'SIZEOF_TIME_T': 8,
- 'SIZEOF_UINTPTR_T': 8,
- 'SIZEOF_VOID_P': 8,
+ 'SIZEOF_SIZE_T': 4,
+ 'SIZEOF_TIME_T': 4,
+ 'SIZEOF_UINTPTR_T': 4,
+ 'SIZEOF_VOID_P': 4,
  'SIZEOF_WCHAR_T': 2,
  'SIZEOF__BOOL': 1,
- 'SOABI': 'cpython-35m-x86_64-cygwin',
+ 'SOABI': 'cpython-35m-i386-cygwin',
  'SRCDIRS': 'Parser Grammar Objects Python Modules Mac Programs',
- 'SRC_GDB_HOOKS': '/usr/src/ports/python35/python35-3.5.6-1.x86_64/src/Python-3.5.6/Tools/gdb/libpython.py',
+ 'SRC_GDB_HOOKS': '/usr/src/ports/python35/python35-3.5.7-1.i686/src/Python-3.5.7/Tools/gdb/libpython.py',
  'STDC_HEADERS': 1,
  'STRICT_SYSV_CURSES': "/* Don't use ncurses extensions */",
  'STRIPFLAG': '-s',
@@ -658,7 +673,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'TESTPYTHON': './python.exe',
  'TESTPYTHONOPTS': '',
  'TESTRUNNER': './python.exe '
-               '/usr/src/ports/python35/python35-3.5.6-1.x86_64/src/Python-3.5.6/Tools/scripts/run_tests.py',
+               '/usr/src/ports/python35/python35-3.5.7-1.i686/src/Python-3.5.7/Tools/scripts/run_tests.py',
  'TESTTIMEOUT': 3600,
  'THREADOBJ': 'Python/thread.o',
  'TIMEMODULE_LIB': 0,
@@ -670,7 +685,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'USE_INLINE': 1,
  'VA_LIST_IS_ARRAY': 0,
  'VERSION': '3.5',
- 'VPATH': '/usr/src/ports/python35/python35-3.5.6-1.x86_64/src/Python-3.5.6',
+ 'VPATH': '/usr/src/ports/python35/python35-3.5.7-1.i686/src/Python-3.5.7',
  'WANT_SIGFPE_HANDLER': 0,
  'WINDOW_HAS_FLAGS': 0,
  'WITH_DOC_STRINGS': 1,
@@ -681,11 +696,11 @@ build_time_vars = {'ABIFLAGS': 'm',
  'WITH_THREAD': 1,
  'WITH_TSC': 0,
  'WITH_VALGRIND': 0,
- 'X87_DOUBLE_ROUNDING': 0,
+ 'X87_DOUBLE_ROUNDING': 1,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/usr/src/ports/python35/python35-3.5.6-1.x86_64/build',
- 'abs_srcdir': '/usr/src/ports/python35/python35-3.5.6-1.x86_64/src/Python-3.5.6',
+ 'abs_builddir': '/usr/src/ports/python35/python35-3.5.7-1.i686/build',
+ 'abs_srcdir': '/usr/src/ports/python35/python35-3.5.7-1.i686/src/Python-3.5.7',
  'datarootdir': '/usr/share',
  'exec_prefix': '/usr',
  'prefix': '/usr',
- 'srcdir': '/usr/src/ports/python35/python35-3.5.6-1.x86_64/src/Python-3.5.6'}
+ 'srcdir': '/usr/src/ports/python35/python35-3.5.7-1.i686/src/Python-3.5.7'}
